pub fn parse_simc(input: &str) -> Result<Profile, SimcParseError>Expand description
Parse a SimC profile string into structured data.
Errors
Returns SimcParseError when the tokenized profile is incomplete or contains invalid values.
pub fn parse_simc(input: &str) -> Result<Profile, SimcParseError>Parse a SimC profile string into structured data.
Returns SimcParseError when the tokenized profile is incomplete or contains invalid values.