#[non_exhaustive]pub struct CryptoError(CryptoErrorKind);Expand description
Errors produced by the node-authentication crypto helpers.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: CryptoErrorKindImplementations
Sourceimpl CryptoError
impl CryptoError
const fn invalid_base64(input: CryptoInput, source: DecodeError) -> Self
const fn invalid_private_key_length(actual: usize) -> Self
const fn invalid_public_key_length(actual: usize) -> Self
const fn invalid_public_key(source: SignatureError) -> Self
const fn invalid_signature_length(actual: usize) -> Self
const fn verification_failed(source: SignatureError) -> Self
Sourcepub const fn input(&self) -> Option<CryptoInput>
pub const fn input(&self) -> Option<CryptoInput>
Encoded input associated with this failure, when one input is responsible.
Sourcepub const fn is_invalid_base64(&self) -> bool
pub const fn is_invalid_base64(&self) -> bool
Whether this failure came from decoding an encoded input.
Sourcepub const fn invalid_length(&self) -> Option<usize>
pub const fn invalid_length(&self) -> Option<usize>
Decoded byte length for a structurally valid base64 value of the wrong size.
Sourcepub const fn is_verification_failed(&self) -> bool
pub const fn is_verification_failed(&self) -> bool
Whether signature verification failed for otherwise valid inputs.